% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/initREMP.R
\name{initREMP}
\alias{initREMP}
\title{RE Annotation Database Initialization}
\usage{
initREMP(arrayType = c("450k", "EPIC"), REtype = c("Alu", "L1"),
  RE = NULL, ncore = NULL, BPPARAM = NULL, export = FALSE,
  work.dir = tempdir(), verbose = FALSE)
}
\arguments{
\item{arrayType}{Illumina methylation array type. Currently \code{"450k"} and \code{"EPIC"} 
are supported. Default = \code{"450k"}.}

\item{REtype}{Type of RE. Currently \code{"Alu"} and \code{"L1"} are supported.}

\item{RE}{A \code{\link{GRanges}} object containing user-specified RE genomic location information. 
If \code{NULL}, the function will retrive RepeatMasker RE database from \code{\link{AnnotationHub}} 
(build hg19).}

\item{ncore}{Number of cores to run parallel computation. By default max number of cores 
available in the machine will be utilized. If \code{ncore = 1}, no parallel computation is allowed.}

\item{BPPARAM}{An optional \code{\link{BiocParallelParam}} instance determining the parallel back-end to 
be used during evaluation. If not specified, default back-end in the machine will be used.}

\item{export}{Logical. Should the returned \code{\link{REMParcel}} object be saved to local machine?
See Details.}

\item{work.dir}{Path to the directory where the generated data will be saved. Valid when 
\code{export = TRUE}. If not specified and \code{export = TRUE}, temporary directory \code{tempdir()} 
will be used.}

\item{verbose}{Logical parameter. Should the function be verbose?}
}
\value{
An \code{\link{REMParcel}} object containing data needed for RE methylation prediction.
}
\description{
\code{initREMP} is used to initialize annotation database for RE methylation prediction. 
Two major RE types in human, Alu element (Alu) and LINE-1 (L1) are available.
}
\details{
Currently, we support two major types of RE in human, Alu and L1. The main purpose of 
\code{initREMP} is to generate and annotate CpG/RE data using the refSeq Gene 
annotation database (provided by \code{\link{AnnotationHub}}). These annotation data are crucial to 
RE methylation prediction in \code{\link{remp}}. Once generated, the data can be reused in the future 
(data can be very large). Therefore, we recommend user to save the output from 
\code{initREMP} to the local machine, so that user only need to run this function once 
as long as there is no change to the RE database. To minimize the size of resulting data file, the generated 
annotation data are only for REs that contain RE-CpGs with neighboring profiled CpGs. By default, the 
neighboring CpGs are confined within 1200 bp flanking window. This window size can be modified using 
\code{\link{remp_options}}.
}
\examples{
data(Alu.demo)
remparcel <- initREMP(arrayType = '450k', REtype = 'Alu', RE = Alu.demo, ncore = 1)
remparcel

# Save the data for later use
saveParcel(remparcel)

}
\seealso{
See \code{\link{remp}} for RE methylation prediction.
}
